@@ -71,14 +71,17 @@ type Response = PlayersWrapper<RawBanData>;
 impl SteamClient {
     /// Gets vector of [BanData] structs
     ///
-    /// If the [SteamID] is invalid or user doesn't exist with the ID
-    /// the API just drops the [BanData] from the response. So don't assume
-    /// the returned [BanDatas](BanData) are in the same order as the
-    /// [SteamIDs](SteamID). Always check the [SteamID] from the [BanData]
-    ///  struct
+    /// Requires an API key. If the [SteamID] is invalid or user doesn't exist
+    /// with the ID the API just drops the [BanData] from the response. So
+    /// don't assume the returned [BanDatas](BanData) are in the same order as
+    /// the [SteamIDs](SteamID). Always check the [SteamID] from the [BanData]
+    /// struct
     pub async fn get_player_bans(&self, ids: Vec<SteamID>) -> Result<Vec<BanData>> {
+        let api_key = self.api_key.as_ref().ok_or(Error {
+            cause: "resolve_vanity_url requires an api key".to_owned(),
+        })?;
         let id_query = concat_steam_ids(ids);
-        let query = format!("key={}&steamids={}", self.api_key, id_query);
+        let query = format!("key={}&steamids={}", api_key, id_query);
         let uri = Uri::builder()
             .scheme("https")
             .authority(AUTHORITY)
@@ -99,7 +102,7 @@ mod tests {
 
     #[test]
     fn works() {
-        let client = SteamClient::new(&env::var("STEAM_API_KEY").unwrap());
+        let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let ban_data =
             tokio_test::block_on(client.get_player_bans(vec![SteamID::from(76561198061271782)]))
                 .unwrap();
