@@ -1,3 +1,5 @@
+use std::net::Ipv4Addr;
+
 use crate::client::SteamClient;
 use crate::steam_id::SteamID;
 use crate::utils::{concat_steam_ids, Error, PlayersWrapper, ResponseWrapper, Result, AUTHORITY};
@@ -59,23 +61,29 @@ impl From<u8> for Status {
 pub struct Summary {
     pub id: SteamID,
     pub visibility: Visibility,
+    /// Profile state, 1 means user has configured the profile
     pub profile_state: u8,
     pub profile_name: String,
+    /// Unix timestamp of users last logoff
     pub last_logoff: u64,
     pub profile_url: String,
+    /// 32x32 pixel image
     pub avatar: String,
+    /// 64x64 pixel image
     pub avatarmedium: String,
+    /// 184x184 pixel image
     pub avatarfull: String,
     pub status: Status,
     pub comment_permission: Option<bool>,
     pub real_name: Option<String>,
-    pub primaryclanid: Option<String>,
+    pub primaryclanid: Option<SteamID>,
+    /// Unix timestamp of users creation
     pub time_created: Option<u64>,
     pub country_code: Option<String>,
     pub city_id: Option<u64>,
     pub game_id: Option<String>,
     pub game_info: Option<String>,
-    pub gameserver_ip: Option<String>,
+    pub gameserver_ip: Option<Ipv4Addr>,
 }
 
 #[derive(Deserialize, Debug)]
@@ -119,13 +127,20 @@ impl From<RawSummary> for Summary {
                 _ => false,
             }),
             real_name: rs.realname,
-            primaryclanid: rs.primaryclanid,
+            primaryclanid: rs
+                .primaryclanid
+                .map(|id| id.parse::<u64>().ok())
+                .flatten()
+                .map(|id| id.into()),
             time_created: rs.timecreated,
             country_code: rs.loccountrycode,
             city_id: rs.loccityid,
             game_id: rs.gameid,
             game_info: rs.gameextrainfo,
-            gameserver_ip: rs.gameserverip,
+            gameserver_ip: rs
+                .gameserverip
+                .map(|ip| ip.parse::<Ipv4Addr>().ok())
+                .flatten(),
         }
     }
 }
@@ -136,19 +151,22 @@ type Response = ResponseWrapper<PlayersWrapper<RawSummary>>;
 impl SteamClient {
     /// Gets vector of player/account [Summaries](Summary).
     ///
-    /// Works with maximum of 100 [SteamIDs](SteamID). If the [SteamID]
-    /// is invalid or user doesn't exist with the ID the API just drops
-    /// the summary from the response. So don't assume the returned
+    /// Requires an API key and works with maximum of 100 [SteamIDs](SteamID).
+    /// If the [SteamID] is invalid or user doesn't exist with the ID the API
+    /// just drops the summary from the response. So don't assume the returned
     /// [Summaries](Summary) are in the same order as the [SteamIDs](SteamID).
     /// Always check the [SteamID] from the [Summary] struct.
     pub async fn get_player_summaries(&self, ids: Vec<SteamID>) -> Result<Vec<Summary>> {
+        let api_key = self.api_key.as_ref().ok_or(Error {
+            cause: "resolve_vanity_url requires an api key".to_owned(),
+        })?;
         if ids.len() > 100 {
             return Err(Error {
                 cause: "Too many IDs for get_player_summaries()".to_owned(),
             });
         }
         let id_query = concat_steam_ids(ids);
-        let query = format!("key={}&steamids={}", self.api_key, id_query);
+        let query = format!("key={}&steamids={}", api_key, id_query);
         let uri = Uri::builder()
             .scheme("https")
             .authority(AUTHORITY)
@@ -170,30 +188,28 @@ mod tests {
 
     #[test]
     fn works_with_single() {
-        let client = SteamClient::new(&env::var("STEAM_API_KEY").unwrap());
+        let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let summary = tokio_test::block_on(
             client.get_player_summaries(vec![SteamID::from(76561198061271782)]),
         )
         .unwrap();
         assert!(summary.len() == 1);
-        //println!("{:?}", summary);
     }
 
     #[test]
     fn works_with_multiple() {
-        let client = SteamClient::new(&env::var("STEAM_API_KEY").unwrap());
+        let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let summary = tokio_test::block_on(client.get_player_summaries(vec![
             SteamID::from(76561198061271782),
             SteamID::from(76561198072766352),
         ]))
         .unwrap();
         assert!(summary.len() == 2);
-        //println!("{:?}", summary);
     }
 
     #[test]
     fn works_with_invalid() {
-        let client = SteamClient::new(&env::var("STEAM_API_KEY").unwrap());
+        let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let summary = tokio_test::block_on(
             client.get_player_summaries(vec![SteamID::from(7656119806127178)]),
         )
