@@ -25,20 +25,20 @@ type Resp = ResponseWrapper<Response>;
 impl SteamClient {
     /// Gets users [SteamID] based on users vanity url
     ///
-    /// Default [URLType] is individual.
+    /// Requires an API key. Default [URLType] is individual.
     pub async fn resolve_vanity_url(
         &self,
         vanity_url: &str,
         url_type: Option<URLType>,
     ) -> Result<SteamID> {
+        let api_key = self.api_key.as_ref().ok_or(Error {
+            cause: "resolve_vanity_url requires an api key".to_owned(),
+        })?;
         let type_query = match url_type {
             Some(url_type) => format!("&url_type={}", url_type as u8),
             None => "".to_owned(),
         };
-        let query = format!(
-            "key={}&vanityurl={}{}",
-            self.api_key, vanity_url, type_query
-        );
+        let query = format!("key={}&vanityurl={}{}", api_key, vanity_url, type_query);
         let uri = Uri::builder()
             .scheme("https")
             .authority(AUTHORITY)
@@ -75,14 +75,14 @@ mod tests {
 
     #[test]
     fn resolve_correct_url() {
-        let client = SteamClient::new(&env::var("STEAM_API_KEY").unwrap());
+        let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let id = tokio_test::block_on(client.resolve_vanity_url("petesammakko", None)).unwrap();
         assert_eq!(id, SteamID::from(76561198061271782));
     }
 
     #[test]
     fn handle_incorrect_url() {
-        let client = SteamClient::new(&env::var("STEAM_API_KEY").unwrap());
+        let client = SteamClient::with_api_key(&env::var("STEAM_API_KEY").unwrap());
         let id = tokio_test::block_on(client.resolve_vanity_url("", None));
         assert_err!(id, "invalid ID should result in error");
     }
